===============
Module Contents
===============

This documentation is automatically generated by scanning all the source code. Parts
may be incomplete.

.. automodule:: pymadx
    :members:
    :undoc-members:
    :show-inheritance:

pymadx.Beam module
------------------

.. automodule:: pymadx.Beam
    :members:
    :undoc-members:
    :show-inheritance:

.. _pymadx-builder:

pymadx.Builder module
---------------------
   
.. automodule:: pymadx.Builder
		:members:
		:undoc-members:
		:show-inheritance:

pymadx.Data module
------------------
   
.. automodule:: pymadx.Data
		:members:
		:undoc-members:
		:show-inheritance:

pymadx.Diagrams module
----------------------

.. automodule:: pymadx.Diagrams
		:members:
		:undoc-members:
		:show-inheritance:

pymadx.Plot module
------------------

.. automodule:: pymadx.Plot
    :members:
    :undoc-members:
    :show-inheritance:

pymadx.Ptc module
-----------------

.. automodule:: pymadx.Ptc
    :members:
    :undoc-members:
    :show-inheritance:

pymadx.PtcAnalysis module
-------------------------

.. automodule:: pymadx.PtcAnalysis
    :members:
    :undoc-members:
    :show-inheritance:
